Attribute macro for marking test functions with Probar metadata.
This macro adds test registration and metadata for the Probar test harness.
Example
ⓘ#[probar_test]
#[probar(timeout_ms = 5000)]
#[probar(category = "player")]
async fn test_player_spawns() {
}